package at.ac.uibk.gitsearch.service.dto;

import java.io.Serializable;
import java.util.Objects;

import io.github.jhipster.service.Criteria;
import io.github.jhipster.service.filter.Filter;
import io.github.jhipster.service.filter.LongFilter;
import io.github.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link at.ac.uibk.gitsearch.domain.UserWatchList} entity. This class is used
 * in {@link at.ac.uibk.gitsearch.web.rest.UserWatchListResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /user-watch-lists?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
public class UserWatchListCriteria implements Serializable, Criteria {

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private StringFilter name;

    private LongFilter userIdId;

    public UserWatchListCriteria() {
    }

    public UserWatchListCriteria(UserWatchListCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.name = other.name == null ? null : other.name.copy();
        this.userIdId = other.userIdId == null ? null : other.userIdId.copy();
    }

    @Override
    public UserWatchListCriteria copy() {
        return new UserWatchListCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public StringFilter getName() {
        return name;
    }

    public void setName(StringFilter name) {
        this.name = name;
    }

    public LongFilter getUserIdId() {
        return userIdId;
    }

    public void setUserIdId(LongFilter userIdId) {
        this.userIdId = userIdId;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final UserWatchListCriteria that = (UserWatchListCriteria) o;
        return
            Objects.equals(id, that.id) &&
            Objects.equals(name, that.name) &&
            Objects.equals(userIdId, that.userIdId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(
        id,
        name,
        userIdId
        );
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "UserWatchListCriteria{" +
                (id != null ? "id=" + id + ", " : "") +
                (name != null ? "name=" + name + ", " : "") +
                (userIdId != null ? "userIdId=" + userIdId + ", " : "") +
            "}";
    }

}
