import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';
import { createRequestOption, SearchWithPagination } from 'app/shared/util/request-util';
import { IUserWatchList } from 'app/shared/model/user-watch-list.model';

type EntityResponseType = HttpResponse<IUserWatchList>;
type EntityArrayResponseType = HttpResponse<IUserWatchList[]>;

@Injectable({ providedIn: 'root' })
export class UserWatchListService {
  public resourceUrl = SERVER_API_URL + 'api/user-watch-lists';
  public currentUserResourceUrl = SERVER_API_URL + 'api/currentuser-watch-lists';
  public resourceSearchUrl = SERVER_API_URL + 'api/_search/user-watch-lists';

  constructor(protected http: HttpClient) {}

  create(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.post<IUserWatchList>(this.resourceUrl, userWatchList, { observe: 'response' });
  }

  createForCurrentUser(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.post<IUserWatchList>(this.currentUserResourceUrl, userWatchList, { observe: 'response' });
  }

  update(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.put<IUserWatchList>(this.resourceUrl, userWatchList, { observe: 'response' });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<IUserWatchList>(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

    /** returns the watchlists of the current user */
  findMyWatchlists(): Observable<EntityArrayResponseType> {
    return this.http.get<IUserWatchList[]>(`${SERVER_API_URL}/api/my-user-watch-lists`, { observe: 'response' });
  }
  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  search(req: SearchWithPagination): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.resourceSearchUrl, { params: options, observe: 'response' });
  }
}
